var hierarchy =
[
    [ "__dlhandle", "struct____dlhandle.html", null ],
    [ "plplot::_N1", "structplplot_1_1__N1.html", null ],
    [ "plplot::_N10", "structplplot_1_1__N10.html", null ],
    [ "plplot::_N11", "structplplot_1_1__N11.html", null ],
    [ "plplot::_N2", "structplplot_1_1__N2.html", null ],
    [ "plplot::_N3", "structplplot_1_1__N3.html", null ],
    [ "plplot::_N4", "structplplot_1_1__N4.html", null ],
    [ "plplot::_N5", "structplplot_1_1__N5.html", null ],
    [ "plplot::_N6", "structplplot_1_1__N6.html", null ],
    [ "plplot::_N7", "structplplot_1_1__N7.html", null ],
    [ "plplot::_N8", "structplplot_1_1__N8.html", null ],
    [ "plplot::_N9", "structplplot_1_1__N9.html", null ],
    [ "plplotc._object", "classplplotc_1_1__object.html", [
      [ "plplotc.PLGraphicsIn", "classplplotc_1_1PLGraphicsIn.html", null ]
    ] ],
    [ "_plm_format", "struct__plm__format.html", null ],
    [ "_plm_version", "struct__plm__version.html", null ],
    [ "_state", "struct__state.html", null ],
    [ "arc_struct", "structarc__struct.html", null ],
    [ "cdImageStruct", "structcdImageStruct.html", null ],
    [ "cdPointStruct", "structcdPointStruct.html", null ],
    [ "circle", "structcircle.html", null ],
    [ "Clipper", "classClipper.html", null ],
    [ "CmdInfo", "structCmdInfo.html", null ],
    [ "Command", "structCommand.html", null ],
    [ "plplot.core.config", "classplplot_1_1core_1_1config.html", null ],
    [ "cont_level", "structcont__level.html", null ],
    [ "cont_line", "structcont__line.html", null ],
    [ "Contourable_Data", "classContourable__Data.html", null ],
    [ "Coord_2d", "classCoord__2d.html", null ],
    [ "Coord_Xformer", "classCoord__Xformer.html", [
      [ "cxx_pltr2", "classcxx__pltr2.html", null ]
    ] ],
    [ "octave_swig_type::cpp_ptr", "structoctave__swig__type_1_1cpp__ptr.html", null ],
    [ "csa", "structcsa.html", null ],
    [ "delaunay", "structdelaunay.html", null ],
    [ "dev_entry", "structdev__entry.html", null ],
    [ "DIR", "structDIR.html", null ],
    [ "dirent", "structdirent.html", null ],
    [ "DrawingObjectsChanger", "classDrawingObjectsChanger.html", null ],
    [ "DrvOpt", "structDrvOpt.html", null ],
    [ "DrvOptCmd", "structDrvOptCmd.html", null ],
    [ "EscText", "structEscText.html", null ],
    [ "FCI_to_FontName_Table", "structFCI__to__FontName__Table.html", null ],
    [ "FontGrabber", "classFontGrabber.html", null ],
    [ "hashtable", "structhashtable.html", null ],
    [ "Hershey_to_Unicode_table", "structHershey__to__Unicode__table.html", null ],
    [ "ht_bucket", "structht__bucket.html", null ],
    [ "IMG_DT", "structIMG__DT.html", null ],
    [ "istack", "structistack.html", null ],
    [ "line", "structline.html", null ],
    [ "lpi", "structlpi.html", null ],
    [ "lweights", "structlweights.html", null ],
    [ "MasterHandler", "classMasterHandler.html", null ],
    [ "MemoryMapHeader", "structMemoryMapHeader.html", null ],
    [ "MJDtimeStruct", "structMJDtimeStruct.html", null ],
    [ "nn_weights", "structnn__weights.html", null ],
    [ "nnai", "structnnai.html", null ],
    [ "nnhpi", "structnnhpi.html", null ],
    [ "nnpi", "structnnpi.html", null ],
    [ "octave_swig_packed", "classoctave__swig__packed.html", null ],
    [ "octave_swig_ref", "classoctave__swig__ref.html", null ],
    [ "octave_swig_type", "classoctave__swig__type.html", null ],
    [ "octave_value_ref", "structoctave__value__ref.html", null ],
    [ "OriginChanger", "classOriginChanger.html", null ],
    [ "pattern", "structpattern.html", null ],
    [ "PDFstrm", "structPDFstrm.html", null ],
    [ "plplot::pladv", "interfaceplplot_1_1pladv.html", null ],
    [ "plplot::plbin", "interfaceplplot_1_1plbin.html", null ],
    [ "plplot::plbop", "interfaceplplot_1_1plbop.html", null ],
    [ "plplot::plbtime", "interfaceplplot_1_1plbtime.html", null ],
    [ "plbuffer", "structplbuffer.html", null ],
    [ "PLBufferingCB", "structPLBufferingCB.html", null ],
    [ "PLCairo", "structPLCairo.html", null ],
    [ "plplot::plcalc_world", "interfaceplplot_1_1plcalc__world.html", null ],
    [ "plplot.core.PLCallbackCT", "interfaceplplot_1_1core_1_1PLCallbackCT.html", null ],
    [ "plplot.core.PLCallbackLabel", "interfaceplplot_1_1core_1_1PLCallbackLabel.html", null ],
    [ "plplot.core.PLCallbackMapform", "interfaceplplot_1_1core_1_1PLCallbackMapform.html", null ],
    [ "plplot::PLcGrid", "structplplot_1_1PLcGrid.html", null ],
    [ "PLcGrid", "structPLcGrid.html", null ],
    [ "plplot::PLcGrid2", "structplplot_1_1PLcGrid2.html", null ],
    [ "PLcGrid2", "structPLcGrid2.html", null ],
    [ "plplot::plclear", "interfaceplplot_1_1plclear.html", null ],
    [ "plplot::plcol0", "interfaceplplot_1_1plcol0.html", null ],
    [ "plplot::plcol1", "interfaceplplot_1_1plcol1.html", null ],
    [ "PLColor", "structPLColor.html", null ],
    [ "plplot::plcolorbar", "interfaceplplot_1_1plcolorbar.html", null ],
    [ "plplot::plconfigtime", "interfaceplplot_1_1plconfigtime.html", null ],
    [ "plplotp::plcont", "interfaceplplotp_1_1plcont.html", null ],
    [ "PLControlPt", "structPLControlPt.html", null ],
    [ "plplot::plcpstrm", "interfaceplplot_1_1plcpstrm.html", null ],
    [ "plplot::plctime", "interfaceplplot_1_1plctime.html", null ],
    [ "PLDev", "structPLDev.html", null ],
    [ "PLDispatchTable", "structPLDispatchTable.html", null ],
    [ "PLDisplay", "structPLDisplay.html", null ],
    [ "plplot::plend1", "interfaceplplot_1_1plend1.html", null ],
    [ "plplot::plenv", "interfaceplplot_1_1plenv.html", null ],
    [ "plplot::pleop", "interfaceplplot_1_1pleop.html", null ],
    [ "plplot::plerrx", "interfaceplplot_1_1plerrx.html", null ],
    [ "plplot::plerry", "interfaceplplot_1_1plerry.html", null ],
    [ "plf2ops_t", "structplf2ops__t.html", null ],
    [ "plplot::plfamadv", "interfaceplplot_1_1plfamadv.html", null ],
    [ "PLfGrid", "structPLfGrid.html", null ],
    [ "PLfGrid2", "structPLfGrid2.html", null ],
    [ "plplot::plfill", "interfaceplplot_1_1plfill.html", null ],
    [ "plplot::plfill3", "interfaceplplot_1_1plfill3.html", null ],
    [ "plplot::plflush", "interfaceplplot_1_1plflush.html", null ],
    [ "plplot::plfont", "interfaceplplot_1_1plfont.html", null ],
    [ "plplot::plfontld", "interfaceplplot_1_1plfontld.html", null ],
    [ "Plframe.Plframe", "classPlframe_1_1Plframe.html", null ],
    [ "PlFrame", "structPlFrame.html", null ],
    [ "plplot::plgchr", "interfaceplplot_1_1plgchr.html", null ],
    [ "plplot::plgcmap1_range", "interfaceplplot_1_1plgcmap1__range.html", null ],
    [ "plplot::plgcol0", "interfaceplplot_1_1plgcol0.html", null ],
    [ "plplot::plgcol0a", "interfaceplplot_1_1plgcol0a.html", null ],
    [ "plplot::plgcolbg", "interfaceplplot_1_1plgcolbg.html", null ],
    [ "plplot::plgcolbga", "interfaceplplot_1_1plgcolbga.html", null ],
    [ "plplot::plgcompression", "interfaceplplot_1_1plgcompression.html", null ],
    [ "plplot::plgdidev", "interfaceplplot_1_1plgdidev.html", null ],
    [ "plplot::plgdiori", "interfaceplplot_1_1plgdiori.html", null ],
    [ "plplot::plgdiplt", "interfaceplplot_1_1plgdiplt.html", null ],
    [ "plplot::plgetcursor", "interfaceplplot_1_1plgetcursor.html", null ],
    [ "plplot::plgfam", "interfaceplplot_1_1plgfam.html", null ],
    [ "plplot::plgfci", "interfaceplplot_1_1plgfci.html", null ],
    [ "plplot::plgfont", "interfaceplplot_1_1plgfont.html", null ],
    [ "plplot::plglevel", "interfaceplplot_1_1plglevel.html", null ],
    [ "plplot::plgpage", "interfaceplplot_1_1plgpage.html", null ],
    [ "plplot::plgra", "interfaceplplot_1_1plgra.html", null ],
    [ "plplot::plgradient", "interfaceplplot_1_1plgradient.html", null ],
    [ "plplot.core.PLGraphicsIn", "classplplot_1_1core_1_1PLGraphicsIn.html", null ],
    [ "plplot_graphics::plgraphicsin", "structplplot__graphics_1_1plgraphicsin.html", null ],
    [ "PLGraphicsIn", "structPLGraphicsIn.html", null ],
    [ "plplot::plgriddata", "interfaceplplot_1_1plgriddata.html", null ],
    [ "plplot::plgspa", "interfaceplplot_1_1plgspa.html", null ],
    [ "plplot::plgstrm", "interfaceplplot_1_1plgstrm.html", null ],
    [ "plplot::plgvpd", "interfaceplplot_1_1plgvpd.html", null ],
    [ "plplot::plgvpw", "interfaceplplot_1_1plgvpw.html", null ],
    [ "plplot::plgxax", "interfaceplplot_1_1plgxax.html", null ],
    [ "plplot::plgyax", "interfaceplplot_1_1plgyax.html", null ],
    [ "plplot::plgzax", "interfaceplplot_1_1plgzax.html", null ],
    [ "plplot::plhist", "interfaceplplot_1_1plhist.html", null ],
    [ "plplot::plhls", "interfaceplplot_1_1plhls.html", null ],
    [ "plplot::plhlsrgb", "interfaceplplot_1_1plhlsrgb.html", null ],
    [ "plplotp::plimagefr", "interfaceplplotp_1_1plimagefr.html", null ],
    [ "plplot::plinit", "interfaceplplot_1_1plinit.html", null ],
    [ "PLiodev", "structPLiodev.html", null ],
    [ "plplot::pljoin", "interfaceplplot_1_1pljoin.html", null ],
    [ "PLLabelDefaults", "structPLLabelDefaults.html", null ],
    [ "plplot::pllegend", "interfaceplplot_1_1pllegend.html", null ],
    [ "plplot::pllightsource", "interfaceplplot_1_1pllightsource.html", null ],
    [ "plplot::plline", "interfaceplplot_1_1plline.html", null ],
    [ "plplot::plline3", "interfaceplplot_1_1plline3.html", null ],
    [ "plplot::pllsty", "interfaceplplot_1_1pllsty.html", null ],
    [ "plplot::plmap", "interfaceplplot_1_1plmap.html", null ],
    [ "plplot::plmapfill", "interfaceplplot_1_1plmapfill.html", null ],
    [ "plplot::plmapline", "interfaceplplot_1_1plmapline.html", null ],
    [ "plplot::plmapstring", "interfaceplplot_1_1plmapstring.html", null ],
    [ "plplot::plmaptex", "interfaceplplot_1_1plmaptex.html", null ],
    [ "PLmDev", "structPLmDev.html", null ],
    [ "PLMemoryMap", "classPLMemoryMap.html", null ],
    [ "plplot::plmeridians", "interfaceplplot_1_1plmeridians.html", null ],
    [ "plplot::plmesh", "interfaceplplot_1_1plmesh.html", null ],
    [ "plplot::plmeshc", "interfaceplplot_1_1plmeshc.html", null ],
    [ "PLmIndex", "structPLmIndex.html", null ],
    [ "plplot::plmkstrm", "interfaceplplot_1_1plmkstrm.html", null ],
    [ "PLNamedMutex", "classPLNamedMutex.html", null ],
    [ "PLNamedMutexLocker", "classPLNamedMutexLocker.html", null ],
    [ "PLOptionInfo", "structPLOptionInfo.html", null ],
    [ "PLOptionTable", "structPLOptionTable.html", null ],
    [ "plplot::plot3d", "interfaceplplot_1_1plot3d.html", null ],
    [ "plplot::plot3dc", "interfaceplplot_1_1plot3dc.html", null ],
    [ "plplot::plpat", "interfaceplplot_1_1plpat.html", null ],
    [ "plplot::plpath", "interfaceplplot_1_1plpath.html", null ],
    [ "plplot", "classplplot.html", null ],
    [ "plplot_graphics", "classplplot__graphics.html", null ],
    [ "plplot_str", "classplplot__str.html", null ],
    [ "plplot_strutils", "classplplot__strutils.html", null ],
    [ "plplot_types", "classplplot__types.html", null ],
    [ "plplot.core.plplotjavacConstants", "interfaceplplot_1_1core_1_1plplotjavacConstants.html", [
      [ "plplot.core.plplotjavac", "classplplot_1_1core_1_1plplotjavac.html", null ],
      [ "plplot.core.PLStream", "classplplot_1_1core_1_1PLStream.html", null ]
    ] ],
    [ "plplot.core.plplotjavacJNI", "classplplot_1_1core_1_1plplotjavacJNI.html", null ],
    [ "plplotp", "classplplotp.html", null ],
    [ "PlPlotter", "structPlPlotter.html", null ],
    [ "plplot::plpoin", "interfaceplplot_1_1plpoin.html", null ],
    [ "plplot::plpoin3", "interfaceplplot_1_1plpoin3.html", null ],
    [ "plplot::plpoly3", "interfaceplplot_1_1plpoly3.html", null ],
    [ "plplot::plprec", "interfaceplplot_1_1plprec.html", null ],
    [ "plplot::plpsty", "interfaceplplot_1_1plpsty.html", null ],
    [ "PLRDev", "structPLRDev.html", null ],
    [ "plplot::plreplot", "interfaceplplot_1_1plreplot.html", null ],
    [ "plplot::plrgb", "interfaceplplot_1_1plrgb.html", null ],
    [ "plplot::plrgb1", "interfaceplplot_1_1plrgb1.html", null ],
    [ "plplot::plrgbhls", "interfaceplplot_1_1plrgbhls.html", null ],
    [ "PLS", "classPLS.html", null ],
    [ "plplot::plschr", "interfaceplplot_1_1plschr.html", null ],
    [ "plplot::plscmap0", "interfaceplplot_1_1plscmap0.html", null ],
    [ "plplot::plscmap0a", "interfaceplplot_1_1plscmap0a.html", null ],
    [ "plplot::plscmap0n", "interfaceplplot_1_1plscmap0n.html", null ],
    [ "plplot::plscmap1", "interfaceplplot_1_1plscmap1.html", null ],
    [ "plplot::plscmap1_range", "interfaceplplot_1_1plscmap1__range.html", null ],
    [ "plplot::plscmap1a", "interfaceplplot_1_1plscmap1a.html", null ],
    [ "plplot::plscmap1l", "interfaceplplot_1_1plscmap1l.html", null ],
    [ "plplot::plscmap1la", "interfaceplplot_1_1plscmap1la.html", null ],
    [ "plplot::plscmap1n", "interfaceplplot_1_1plscmap1n.html", null ],
    [ "plplot::plscol0", "interfaceplplot_1_1plscol0.html", null ],
    [ "plplot::plscol0a", "interfaceplplot_1_1plscol0a.html", null ],
    [ "plplot::plscolbg", "interfaceplplot_1_1plscolbg.html", null ],
    [ "plplot::plscolbga", "interfaceplplot_1_1plscolbga.html", null ],
    [ "plplot::plscolor", "interfaceplplot_1_1plscolor.html", null ],
    [ "plplot::plscompression", "interfaceplplot_1_1plscompression.html", null ],
    [ "plplot::plsdidev", "interfaceplplot_1_1plsdidev.html", null ],
    [ "plplot::plsdimap", "interfaceplplot_1_1plsdimap.html", null ],
    [ "plplot::plsdiori", "interfaceplplot_1_1plsdiori.html", null ],
    [ "plplot::plsdiplt", "interfaceplplot_1_1plsdiplt.html", null ],
    [ "plplot::plsdiplz", "interfaceplplot_1_1plsdiplz.html", null ],
    [ "plplot::plseed", "interfaceplplot_1_1plseed.html", null ],
    [ "plplot::plsesc", "interfaceplplot_1_1plsesc.html", null ],
    [ "plplot::plsetmapformc", "interfaceplplot_1_1plsetmapformc.html", null ],
    [ "plplot::plsetmapformc::plsfam", "interfaceplplot_1_1plsetmapformc_1_1plsfam.html", null ],
    [ "plplot::plsetmapformc::plsfci", "interfaceplplot_1_1plsetmapformc_1_1plsfci.html", null ],
    [ "plplot::plsetmapformc::plsfont", "interfaceplplot_1_1plsetmapformc_1_1plsfont.html", null ],
    [ "plplotp::plshade", "interfaceplplotp_1_1plshade.html", null ],
    [ "plplotp::plshades", "interfaceplplotp_1_1plshades.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plsmaj", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsmaj.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plsmin", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsmin.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plsori", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsori.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plspage", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plspage.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plspause", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plspause.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plsstrm", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plsstrm.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plssub", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssub.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plssym", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plssym.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstar", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstar.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform.html", null ],
    [ "PLStream", "structPLStream.html", null ],
    [ "plstream", "classplstream.html", [
      [ "wxPLplotstream", "classwxPLplotstream.html", null ]
    ] ],
    [ "PLStrip", "structPLStrip.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstripa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripa.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstripc", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripc.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstripd", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstripd.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plstyl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plstyl.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsurf3d", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3d.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsurf3dl", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsurf3dl.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsvect", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvect.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsvpa", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsvpa.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsxax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsxax.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsyax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsyax.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plsym", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plsym.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plszax", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plszax.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::pltext", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1pltext.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plvasp", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvasp.html", null ],
    [ "plplotp::plvect", "interfaceplplotp_1_1plvect.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plvpas", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvpas.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plvpor", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvpor.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plvsta", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plvsta.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plw3d", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plw3d.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plwidth", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plwidth.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plwind", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plwind.html", null ],
    [ "PLWindow", "structPLWindow.html", null ],
    [ "Plframe.PlXframe", "classPlframe_1_1PlXframe.html", null ],
    [ "plplot::plsetmapformc::plslabelfunc::plstransform::plxormod", "interfaceplplot_1_1plsetmapformc_1_1plslabelfunc_1_1plstransform_1_1plxormod.html", null ],
    [ "point", "structpoint.html", null ],
    [ "PSDev", "structPSDev.html", null ],
    [ "pt", "structpt.html", null ],
    [ "PyHeapTypeObject", "structPyHeapTypeObject.html", null ],
    [ "QGlobalSpace", "classQGlobalSpace.html", null ],
    [ "QSASConfigStruct", "structQSASConfigStruct.html", null ],
    [ "QtPLDriver", "classQtPLDriver.html", null ],
    [ "Rand", "classRand.html", null ],
    [ "Scaler", "classScaler.html", null ],
    [ "square", "structsquare.html", null ],
    [ "SVG", "structSVG.html", null ],
    [ "swig_cast_info", "structswig__cast__info.html", null ],
    [ "swig_const_info", "structswig__const__info.html", null ],
    [ "swig_globalvar", "structswig__globalvar.html", null ],
    [ "SWIG_JavaExceptions_t", "structSWIG__JavaExceptions__t.html", null ],
    [ "swig_lua_attribute", "structswig__lua__attribute.html", null ],
    [ "swig_lua_class", "structswig__lua__class.html", null ],
    [ "swig_lua_const_info", "structswig__lua__const__info.html", null ],
    [ "swig_lua_method", "structswig__lua__method.html", null ],
    [ "swig_lua_rawdata", "structswig__lua__rawdata.html", null ],
    [ "swig_lua_userdata", "structswig__lua__userdata.html", null ],
    [ "swig_lua_var_info", "structswig__lua__var__info.html", null ],
    [ "swig_module_info", "structswig__module__info.html", null ],
    [ "swig_octave_class", "structswig__octave__class.html", null ],
    [ "swig_octave_member", "structswig__octave__member.html", null ],
    [ "swig_type_info", "structswig__type__info.html", null ],
    [ "swig_varlinkobject", "structswig__varlinkobject.html", null ],
    [ "SwigPyClientData", "structSwigPyClientData.html", null ],
    [ "SwigPyObject", "structSwigPyObject.html", null ],
    [ "SwigPyPacked", "structSwigPyPacked.html", null ],
    [ "TAI_UTC", "structTAI__UTC.html", null ],
    [ "tclMatrix", "structtclMatrix.html", null ],
    [ "tclMatrixXtnsnDescr", "structtclMatrixXtnsnDescr.html", null ],
    [ "TextObjectsChanger", "classTextObjectsChanger.html", null ],
    [ "TextSizeInfo", "structTextSizeInfo.html", null ],
    [ "TkDev", "structTkDev.html", null ],
    [ "TkwDev", "structTkwDev.html", null ],
    [ "TkwDisplay", "structTkwDisplay.html", null ],
    [ "triangle", "structtriangle.html", null ],
    [ "triangle_neighbours", "structtriangle__neighbours.html", null ],
    [ "Unicode_to_Type1_table", "structUnicode__to__Type1__table.html", null ],
    [ "wxPLDevice", "classwxPLDevice.html", null ],
    [ "wxPLplotwindow< WXWINDOW >", "classwxPLplotwindow.html", null ],
    [ "XwDev", "structXwDev.html", null ],
    [ "XwDisplay", "structXwDisplay.html", null ]
];